@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use strict;
 use warnings;
@@ -95,7 +95,7 @@ sub	config2perl {
 	}
 	# this is a warning:
 	# we can not be sure if this <% xyz %> is part of the content or a forgotten templated variable
-	if( $contents =~ /\Q${tvop}\E!(:?(:?begin-verbatim-section)|(:?end-verbatim-section))%*>/ ){ warn "--begin content:\n".$contents."\n--end content.\n".__PACKAGE__.'::config2perl()'." (line ".__LINE__.") : warning, there may still be remains of templated variables in the specified content, see above what remained after all template variables substitutions were done." }
+	if( $contents =~ /\Q${tvop}\E\s*!(:?(:?begin-verbatim-section)|(:?end-verbatim-section))\s*\Q${tvcl}\E/ ){ warn "--begin content:\n".$contents."\n--end content.\n".__PACKAGE__.'::config2perl()'." (line ".__LINE__.") : warning, there may still be remains of templated variables in the specified content, see above what remained after all template variables substitutions were done." }
 
 	# secondly, remove the VERBATIM multiline sections and transform them.
 	# Comments inside the verbatim section will NOT BE touched.
@@ -104,7 +104,7 @@ sub	config2perl {
 	# then does the comments and then replaces the code with the verbatim section at the very end
 	my @verbs;
 	my $idx = 0;
-	while( $contents =~ s/\Q${tvop}\E*begin-verbatim-section\s*\Q${tvcl}\E(.+?)\Q${tvop}\E*end-verbatim-section\s*\Q${tvcl}\E/"${tvop}verbatim-section-${idx}${tvcl}"/s ){
+	while( $contents =~ s/\Q${tvop}\E\s*begin-verbatim-section\s*\Q${tvcl}\E(.*?)\Q${tvop}\E\s*end-verbatim-section\s*\Q${tvcl}\E/"___my___verbatim-section-${idx}___my___"/s ){
 		my $vc = $1;
 		# remove from start and end of whole string newlines+spaces
 		$vc =~ s/^[\n\t ]+//;
@@ -122,14 +122,14 @@ sub	config2perl {
 		$idx++;
 	}
 
-	# thirdly, replace all strings with indexed markers
+	# thirdly, replace all JSON strings (keys or values) with indexed markers
 	# so that their contained comments
 	# to be left intact after the comment substitution which will
 	# be done later on.
 	my @stringsubs;
 	if( $remove_comments_in_strings == 0 ){
 		$idx = 0;
-		while( $contents =~ s/(?<![\\])"((?:.(?!(?<![\\])"))*.?)"/___EJSTRING($idx)___/ ){
+		while( $contents =~ s/(?<![\\])"((?:.(?!(?<![\\])"))*.?)"/___my___EJSTRING($idx)___my___/ ){
 			push @stringsubs, $1;
 			$idx++;
 		}
@@ -158,12 +158,12 @@ sub	config2perl {
 		# 'opening' and 'closing' can be any string
 		# And need not be balanced e.g. <<< and >>
 		# And can be the same e.g. <<< and <<<
-		my $op = $1; my $cl = $2;
-		if( $cl =~ /^\s*$/ ){
+		my $coop = $1; my $cocl = $2;
+		if( $cocl =~ /^\s*$/ ){
 			# TODO: we must also remove the newline left!
-			$contents =~ s/${op}.*$//mg;
+			$contents =~ s/\Q${coop}\E.*$//mg;
 		} else {
-			$contents =~ s/${op}(?:(?!${cl}).)*${cl}\n?//sg;
+			$contents =~ s/\Q${coop}\E(?:(?!\Q${cocl}\E\s*).)*\Q${cocl}\E\s*\n?//sg;
 		}
 	}
 	if( $tc =~ /[a-z]/i ){ warn __PACKAGE__.'::config2perl()'." (line ".__LINE__.") : error, comments style '${commentstyle}' was not understood, this is what was left after parsing it: '${tc}'."; return undef }
@@ -176,13 +176,13 @@ sub	config2perl {
 		$idx = 0;
 		for($idx=scalar(@stringsubs);$idx-->0;){
 			my $astring = $stringsubs[$idx];
-			$contents =~ s/___EJSTRING\($idx\)___/"${astring}"/g
+			$contents =~ s/___my___EJSTRING\($idx\)___my___/"${astring}"/g
 		}
 	}
 
 	# and now substitute the transformed verbatim sections back
 	for($idx=scalar(@verbs);$idx-->0;){
-		$contents =~ s/\Q${tvop}\Everbatim-section-${idx}\Q${tvcl}\E/$verbs[$idx]/g;
+		$contents =~ s/___my___verbatim-section-${idx}___my___/$verbs[$idx]/g;
 	}
 
 	if( $debug > 0 ){ warn $contents."\n\n".__PACKAGE__.'::config2perl()'." (line ".__LINE__.") : produced above standard JSON from enhanced JSON content." }
@@ -201,7 +201,7 @@ Config::JSON::Enhanced - JSON-based config with C/Shell-style comments, verbatim
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -266,7 +266,7 @@ Here is an example:
     # standard JSON with user-specified data.
     # Notice that the opening and closing tags enclosing variable
     # names can be customised using the 'tags' input parameter,
-    # so as to avoid clashes.
+    # so as to avoid clashes with content in the JSON.
     my $configdata = <<'EOJ';
      {
        "d" : [1,2,<% tempvar0 %>],
@@ -279,7 +279,8 @@ Here is an example:
         'string' => $configdata,
         'commentstyle' => "C,shell,CPP",
         # optionally customise the tags enclosing the variables
-        #'tags' => ['<%', '%>'],
+        # when you want to avoid clashes with other strings in JSON
+        #'tags' => ['<%', '%>'], # <<< these are the default values
         # user-specified data to replace the variables in
         # the "enhanced" JSON above:
         'variable-substitutions' => {
@@ -430,7 +431,11 @@ For example C<custom(E<lt>E<lt>)(E<gt>E<gt>)> or
 C<custom({{)(})> or C<custom(REM)()> or C<custom(E<lt>E<lt>E<lt>E<lt>)(E<gt>E<gt>)>.
 C<OPENINGTAG> and C<CLOSINGTAG> do not need to be of
 the same character length as it is
-obvious from the previous example.
+obvious from the previous example. A word of warning:
+the regex for identifying comments (and variables and verbatim sections)
+has the custom tags escaped for special regex characters
+(with the C<\Q ... \E> construct). So you are pretty safe in using
+any character. Please report weird behaviour.
 
 =back
 
@@ -471,7 +476,11 @@ set to 1, then the JSON string will become C<hello>. If set to
 =item * C<tags> : specify the opening and closing tags for template
 variables and verbatim section as an ARRAYref of exactly 2 items (the
 opening and the closing tags). By default the opening tag is C<E<gt>%>
-and the closing tag is C<%E<lt>>.
+and the closing tag is C<%E<lt>>. A word of warning:
+the regex for identifying variables and verbatim sections (and comments)
+has the custom tags escaped for special regex characters
+(with the C<\Q ... \E> construct). So you are pretty safe in using
+any character. Please report weird behaviour.
 
 If you set C<tags => [ '[::', '::]' ]>
 then your template variables should look like this: C<{:: var1 ::]> and
@@ -669,11 +678,11 @@ the same character sequence for these tags and avoid clashes
 and unexpected substitutions. C<E<lt>%> and C<%E<gt>> are the default
 tags.
 
-Similarly, C<custom> comment style can be employed if your
+Similarly, C<custom> comment style (specifying what should be
+the opening and, optionally, closing tags) can be employed if your
 JSON strings contain something that looks like comments
 and you want to avoid their removal.
 
-
 =head1 WARNINGS/CAVEATS
 
 In order to remove comments within strings, a simplistic regular
@@ -687,6 +696,10 @@ possible that setting parameter C<remove-comments-in-strings> to 1
 to sub L<config2perl> to cause unexpected results. Please
 report these cases, see L<SUPPORT>.
 
+The regex for identifying comments, variables and verbatim sections
+has the custom tags escaped for special regex characters
+(with the C<\Q ... \E> construct). So you are pretty safe in using
+any character. Please report weird behaviour.
 
 =head1 AUTHOR
 
